@@ -89,7 +89,7 @@ class DataFrame:
     def get_generator(self):
         return self.__generator
     
-    def remove_stopwords(self, column, language_or_stopwords_list='english'):
+    def remove_stopwords(self, column, language_or_stopwords_list='english', in_place=True):
         if isinstance(language_or_stopwords_list, list) is True:
             stopwords = language_or_stopwords_list
         elif language_or_stopwords_list == 'arabic':
@@ -97,11 +97,12 @@ class DataFrame:
         else:
             nltk.download('stopwords')
             stopwords = nltk.corpus.stopwords.words(language_or_stopwords_list)
-        self.transform_column(column, column, DataFrame.remove_stopwords_lambda, True, stopwords)
+        self.transform_column(column, column, DataFrame.remove_stopwords_lambda, in_place, stopwords)
         return self.__dataframe
     
     @staticmethod
     def remove_stopwords_lambda(document, stopwords_list):
+        document = str.lower(document)
         stopwords = stopwords_list
         words = word_tokenize(document)
         for w in words:
